import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'code',
    label: '报修单号'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_REQ_STATUS)
    },
    fieldName: 'status',
    label: '报修状态'
  },

  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'reqDept',
    label: '报修部门',
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'reqUser',
    label: '报修人'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_REQ_TYPE)
    },
    fieldName: 'reqType',
    label: '报修类型'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_FAULT_TYPE)
    },
    fieldName: 'faultType',
    label: '故障类别'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.REPAIR_URGENCY_LEVEL)
    },
    fieldName: 'urgencyLevel',
    label: '紧急程度'
  },
  {
    component: 'RangePicker',
    fieldName: 'reqTime',
    label: '报修时间'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '报修单号',
    field: 'code',
    minWidth: 160,
    fixed: 'left'
  },
  {
    title: '处理状态',
    field: 'status',
    minWidth: 100,
    fixed: 'left',
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.REPAIR_REQ_STATUS);
      }
    }
  },
  {
    title: '报修类型',
    field: 'reqType',
    sortable: true,
    minWidth: 100,
    slots: {
      default: ({ row }) => {
        return renderDict(row.reqType, DictEnum.REPAIR_REQ_TYPE);
      }
    }
  },
  {
    title: '报修时间',
    field: 'reqTime',
    sortable: true,
    minWidth: 200
  },
  {
    title: '故障类别',
    field: 'faultType',
    minWidth: 100,
    slots: {
      default: ({ row }) => {
        return renderDict(row.faultType, DictEnum.REPAIR_FAULT_TYPE);
      }
    }
  },
  {
    title: '报修部门',
    field: 'reqDeptName',
    minWidth: 100
  },
  {
    title: '报修人',
    field: 'reqUserName',
    minWidth: 100
  },
  {
    title: '故障描述',
    field: 'reqDesc',
    minWidth: 120
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 130
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
    },
    fieldName: 'reqType',
    label: '报修类型',
    help: `报修类型，如设备故障、工具（治具）故障等`
  },
  {
    component: 'Input',
    fieldName: 'code',
    label: '报修单号'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'equId',
    label: '设备id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.REPAIR_REQ_STATUS)
    },
    fieldName: 'status',
    label: '处理状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'reqTime',
    label: '报修时间'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'occTime',
    label: '发生时间'
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.REPAIR_FAULT_TYPE)
    },
    fieldName: 'faultType',
    label: '故障类别'
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.REPAIR_URGENCY_LEVEL)
    },
    fieldName: 'urgencyLevel',
    label: '紧急程度'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'reqDesc',
    label: '故障描述'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'reqDept',
    label: '报修部门',
    help: `报修人员所属部门`
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'reqUser',
    label: '报修人'
  }
];
